@@ -5,15 +5,16 @@ use 5.010;
 use utf8;
 package App::AppSpec;
 use Term::ANSIColor;
+use YAML::PP;
 use File::Basename qw/ dirname /;
 
-our $VERSION = '0.001_001'; # TRIAL VERSION
+our $VERSION = '0.002_001'; # TRIAL VERSION
 
-use base 'App::Spec::Run';
+use base 'App::Spec::Run::Cmd';
 
 sub _read_spec {
-    my ($self) = @_;
-    my $parameters = $self->parameters;
+    my ($self, $run) = @_;
+    my $parameters = $run->parameters;
 
     my $spec_file = $parameters->{spec_file};
     my $spec = App::Spec->read($spec_file);
@@ -21,14 +22,14 @@ sub _read_spec {
 }
 
 sub cmd_completion {
-    my ($self) = @_;
-    my $options = $self->options;
-    my $parameters = $self->parameters;
+    my ($self, $run) = @_;
+    my $options = $run->options;
+    my $parameters = $run->parameters;
 
     my $shell = $options->{zsh} ? "zsh" : $options->{bash} ? "bash" : '';
     die "Specify which shell" unless $shell;
 
-    my $spec = $self->_read_spec;
+    my $spec = $self->_read_spec($run);
     my $completion = $spec->generate_completion(
         shell => $shell,
     );
@@ -36,27 +37,31 @@ sub cmd_completion {
 }
 
 sub generate_pod {
-    my ($self) = @_;
-    my $parameters = $self->parameters;
+    my ($self, $run) = @_;
+    my $parameters = $run->parameters;
 
-    my $spec = $self->_read_spec;
-    my $pod = $spec->generate_pod(
+    my $spec = $self->_read_spec($run);
+
+    require App::Spec::Pod;
+    my $generator = App::Spec::Pod->new(
+        spec => $spec,
     );
+    my $pod = $generator->generate;
+
     say $pod;
 }
 
 sub cmd_validate {
-    my ($self) = @_;
-    my $options = $self->options;
-    my $parameters = $self->parameters;
-    my $color = $self->colorize;
+    my ($self, $run) = @_;
+    my $options = $run->options;
+    my $parameters = $run->parameters;
 
     my @errors;
     require App::AppSpec::Schema::Validator;
     my $validator = App::AppSpec::Schema::Validator->new;
     my $spec_file = $parameters->{spec_file};
     if (ref $spec_file eq 'SCALAR') {
-        my $spec = YAML::XS::Load($$spec_file);
+        my $spec = YAML::PP::Load($$spec_file);
         @errors = $validator->validate_spec($spec);
     }
     else {
@@ -65,21 +70,17 @@ sub cmd_validate {
     binmode STDOUT, ":encoding(utf-8)";
     if (@errors) {
         print $validator->format_errors(\@errors);
-        $color and print color 'red';
-        say "Not valid!";
-        $color and print color 'reset';
+        say $run->colored(out => red => "Not valid!");
     }
     else {
-        $color and print color 'bold green';
-        say "Validated ✓";
-        $color and print color 'reset';
+        say $run->colored(out => [qw/ bold green /] => "Validated ✓");
     }
 }
 
 sub cmd_new {
-    my ($self) = @_;
-    my $options = $self->options;
-    my $params = $self->parameters;
+    my ($self, $run) = @_;
+    my $options = $run->options;
+    my $params = $run->parameters;
     my $dist_path = $params->{path};
     require File::Path;
 
@@ -109,21 +110,23 @@ class: $class
 title: 'app title'
 description: 'app description'
 options:
-- name: "some-option"
-  type: "flag"
-  summary: "option summary"
+- name: some-flag
+  type: flag
+  summary: option summary
+- spec: other-option=s --another option
 EOM
+    my $subname = $options->{"with-subcommands"} ? "mycommand" : "execute";
     my $module = <<"EOM";
 package $class;
 use strict;
 use warnings;
 use feature qw/ say /;
-use base 'App::Spec::Run';
+use base 'App::Spec::Run::Cmd';
 
-sub mycommand \{
-    my (\$self) = \@_;
-    my \$options = \$self->options;
-    my \$parameters = \$self->parameters;
+sub $subname \{
+    my (\$self, \$run) = \@_;
+    my \$options = \$run->options;
+    my \$parameters = \$run->parameters;
 
     say "Hello world";
 \}
@@ -137,6 +140,7 @@ use warnings;
 
 use App::Spec;
 use App::AppSpec;
+use $class;
 use File::Share qw/ dist_file /;
 
 my \$specfile = dist_file("$dist", "$name-spec.yaml");
@@ -151,7 +155,7 @@ subcommands:
       summary: "Summary for mycommand"
       op: "mycommand"
       description: "Description for mycommand"
-    parameters:
+      parameters:
       - name: "myparam"
         summary: "Summary for myparam"
         required: 1
@@ -165,7 +169,7 @@ EOM
     File::Path::make_path("$dist/bin");
     File::Path::make_path(dirname $module_path);
     my $specfile = "$dist/share/$name-spec.yaml";
-    say "Writig spec to $specfile";
+    say "Writing spec to $specfile";
     open my $fh, ">", $specfile or die $!;
     print $fh $spec;
     close $fh;
@@ -203,6 +207,11 @@ completion or pod from it.
 
 =back
 
+=head1 LICENSE
+
+This library is free software and may be distributed under the same terms
+as perl itself.
+
 =cut
 
 1;
