@@ -2,16 +2,16 @@ use strict;
 use warnings;
 package App::AppSpec::Schema::Validator;
 
-our $VERSION = '0.001_001'; # TRIAL VERSION
+our $VERSION = '0.002_001'; # TRIAL VERSION
 
 use App::Spec;
 use File::Share qw/ dist_file /;
-use YAML::XS;
+use YAML::PP;
 use Moo;
 
 sub validate_spec_file {
     my ($self, $file) = @_;
-    my $spec = YAML::XS::LoadFile($file);
+    my $spec = YAML::PP::LoadFile($file);
     return $self->validate_spec($spec);
 }
 
@@ -19,10 +19,9 @@ sub validate_spec {
     my ($self, $spec) = @_;
     eval { require JSON::Validator }
         or die "JSON::Validator is needed for validating a spec file";
-    my $file = dist_file("App-Spec", "schema.yaml");
-    my $schema = YAML::XS::LoadFile($file);
+    my $schema_file = dist_file("App-Spec", "schema.yaml");
     my $json_validator = JSON::Validator->new;
-    $json_validator->schema($schema);
+    $json_validator->schema($schema_file);
     my @errors = $json_validator->validate($spec);
     return @errors;
 }
